@@ -1,7 +1,7 @@
 import logging
 
 
-from src.commands.commandbase import CommandBase
+from commands.commandbase import CommandBase
 
 
 log = logging.getLogger("").getChild(__name__)
